Package: future.callr
Version: 1.0.0
Depends: R (>= 3.4.0), future (>= 1.58.0)
Imports: parallelly, callr
Suggests: globals, future.apply, listenv, markdown, R.rsp
VignetteBuilder: R.rsp
Title: A Future API for Parallel Processing using 'callr'
Authors@R: c(person("Henrik", "Bengtsson",
                    role = c("aut", "cre", "cph"),
                    email = "henrikb@braju.com",
                    comment = c(ORCID = "0000-0002-7579-5165")))
Description: Implementation of the Future API <doi:10.32614/RJ-2021-048> on top of the 'callr' package.  This allows you to process futures, as defined by the 'future' package, in parallel out of the box, on your local (Linux, macOS, Windows, ...) machine.  Contrary to backends relying on the 'parallel' package (e.g. 'future::multisession') and socket connections, the 'callr' backend provided here can run more than 125 parallel R processes.
License: Apache License (>= 2)
LazyLoad: TRUE
URL: https://future.callr.futureverse.org,
        https://github.com/futureverse/future.callr
BugReports: https://github.com/futureverse/future.callr/issues
Language: en-US
Encoding: UTF-8
Config/roxygen2/version: 8.0.0
NeedsCompilation: no
Packaged: 2026-06-21 23:21:44 UTC; hb
Author: Henrik Bengtsson [aut, cre, cph] (ORCID:
    <https://orcid.org/0000-0002-7579-5165>)
Maintainer: Henrik Bengtsson <henrikb@braju.com>
Repository: CRAN
Date/Publication: 2026-06-22 05:20:22 UTC
Built: R 4.5.2; ; 2026-06-22 11:46:50 UTC; unix
