# Generated by roxygen2: do not edit by hand

S3method(getFutureBackendConfigs,CallrFuture)
S3method(interruptFuture,CallrFutureBackend)
S3method(launchFuture,CallrFutureBackend)
S3method(nbrOfFreeWorkers,CallrFutureBackend)
S3method(nbrOfWorkers,CallrFutureBackend)
S3method(print,CallrFuture)
S3method(resolved,CallrFuture)
S3method(result,CallrFuture)
S3method(stopWorkers,CallrFutureBackend)
export(CallrFutureBackend)
export(callr)
importFrom(callr,r_bg)
importFrom(future,FutureBackend)
importFrom(future,FutureError)
importFrom(future,FutureInterruptError)
importFrom(future,FutureWarning)
importFrom(future,UnexpectedFutureResultError)
importFrom(future,cancel)
importFrom(future,future)
importFrom(future,interruptFuture)
importFrom(future,launchFuture)
importFrom(future,nbrOfFreeWorkers)
importFrom(future,nbrOfWorkers)
importFrom(future,resolved)
importFrom(future,result)
importFrom(future,run)
importFrom(future,stopWorkers)
importFrom(parallelly,availableCores)
importFrom(parallelly,killNode)
importFrom(utils,capture.output)
importFrom(utils,packageVersion)
importFrom(utils,str)
importFrom(utils,tail)
